Tour TOC
Date: 08 14, 2001 3:14:09 PM

The VisualText Quick Tour
Table of Contents

Title | Description
Intro | Introduction to VisualText's Power
Screen Layout | General layout of the Graphic User Interface
Loading Analyzer | Load the demonstration analyzer "Corporate"
Log | Monitoring the Log File
Text Tab | Text for developing text analyzers
Running the Analyzer | Run the analyzer on the text
Output | Examining the output
Parse Trees | Structures built by the analyzer
Ana Tab | Building the analyzer sequence
Pass Files | Rules and Code in pass files
Gram Tab | Automatic Rule Generation
Debugging | Examining the details of the analyzer at work
Knowledge Base | Exploring the Knowledge Base
Find | Finding words and concepts in files